@@ -15,4 +15,4 @@ except PackageNotFoundError:  # pragma: no cover
 finally:
     del version, PackageNotFoundError
 
-from .backedH5 import H5Backed
\ No newline at end of file
+from .backedH5 import H5BackedData
\ No newline at end of file
