@@ -1,5 +1,5 @@
 import scipy.sparse as sp
-from filebackedarray import H5Backed
+from filebackedarray import H5BackedData
 
 __author__ = "jkanche"
 __copyright__ = "jkanche"
@@ -7,20 +7,20 @@ __license__ = "MIT"
 
 
 def test_h5_backed():
-    assay = H5Backed("tests/data/tenx.sub.h5", "matrix")
+    assay = H5BackedData("tests/data/tenx.sub.h5", "matrix")
 
     assert assay is not None
-    assert isinstance(assay, H5Backed)
+    assert isinstance(assay, H5BackedData)
     assert assay.shape == (1000, 3005)
     assert assay.mat_format == "csc_matrix"
     assert assay.dtype is not None
 
 
 def test_h5_backed_slice():
-    assay = H5Backed("tests/data/tenx.sub.h5", "matrix")
+    assay = H5BackedData("tests/data/tenx.sub.h5", "matrix")
 
     assert assay is not None
-    assert isinstance(assay, H5Backed)
+    assert isinstance(assay, H5BackedData)
     assert assay.shape == (1000, 3005)
 
     asy_slice = assay[0:100, 1:101]
